@@ -26,7 +26,7 @@ after runing this component.
         _room2ds: A list of Room2Ds for which adjacencent segments will be
             intersected.
         _run: Set to True to run the component.
-    
+
     Returns:
         int_room2ds: An array of Room2Ds that have been intersected with one another.
             Note that these Room2Ds lack all assigned boundary conditions, glazing
@@ -35,10 +35,10 @@ after runing this component.
 
 ghenv.Component.Name = "DF Intersect Room2Ds"
 ghenv.Component.NickName = 'IntRoom2D'
-ghenv.Component.Message = '1.4.0'
+ghenv.Component.Message = '1.5.1'
 ghenv.Component.Category = "Dragonfly"
 ghenv.Component.SubCategory = '0 :: Create'
-ghenv.Component.AdditionalHelpFromDocStrings = "4"
+ghenv.Component.AdditionalHelpFromDocStrings = '0'
 
 
 try:  # import the core dragonfly dependencies
@@ -55,4 +55,9 @@ except ImportError as e:
 
 # add an compile toggle, set _compile to True to run the function
 if all_required_inputs(ghenv.Component) and _run:
-    int_room2ds = Room2D.intersect_adjacency(_room2ds, tolerance)
\ No newline at end of file
+    rooms = []
+    for room in _room2ds:
+        rm = room.duplicate()
+        rm.remove_colinear_vertices(tolerance)
+        rooms.append(rm)
+    int_room2ds = Room2D.intersect_adjacency(rooms, tolerance)
\ No newline at end of file
